@@ -52,59 +52,47 @@
 #'
 control.dcm <- function(type,
                         nsteps,
-                        dt,
-                        odemethod,
-                        new.mod,
-                        print.mod,
-                        verbose,
+                        dt = 1,
+                        odemethod = "rk4",
+                        new.mod = NULL,
+                        print.mod = FALSE,
+                        verbose = TRUE,
                         ...) {
 
-  ## Pull parameters
-  out <- as.list(match.call(expand.dots = TRUE)[-1])
-
-
-  ## Split lists
-  out <- split_list(out)
-
-
-  ## Eval args
-  out <- eval_list(out)
+  # Get arguments
+  p <- list()
+  formal.args <- formals(sys.function())
+  formal.args[["..."]] <- NULL
+  for (arg in names(formal.args)) {
+    if (as.logical(mget(arg) != "")) {
+      p[arg] <- list(get(arg))
+    }
+  }
+  dot.args <- list(...)
+  names.dot.args <- names(dot.args)
+  if (length(dot.args) > 0) {
+    for (i in 1:length(dot.args)) {
+      p[[names.dot.args[i]]] <- dot.args[[i]]
+    }
+  }
 
 
   ## Defaults and checks
-  if (is.null(out$nsteps)) {
+  if (is.null(p$nsteps)) {
     stop("Specify nsteps")
   }
 
-  # Respecify dt as sequence vector
-  if (is.null(out$dt)) {
-    dt <- 1
-  }
-  out$dt <- seq(1, nsteps, dt)
-
-  if (is.null(out$odemethod)) {
-    out$odemethod <- "rk4"
-  }
-  if (is.null(out$new.mod)) {
-    out$new.mod <- NULL
-  }
-  if (is.null(out$print.mod)) {
-    out$print.mod <- FALSE
-  }
-  if (is.null(out$verbose)) {
-    out$verbose <- TRUE
-  }
 
   # Check type for integrated models
-  if (is.null(out$new.mod)) {
-    if (is.null(out$type) || !(out$type %in% c("SI", "SIS", "SIR"))) {
-      stop("Specify type as \"SI\", \"SIS\", or \"SIR\" ")
+  if (is.null(p$new.mod)) {
+    if (is.null(p$type) || !(p$type %in% c("SI", "SIS", "SIR"))) {
+      stop("Specify type as \"SI\", \"SIS\", or \"SIR\" ", call. = FALSE)
     }
   }
 
   ## Output
-  class(out) <- "control.dcm"
-  return(out)
+  class(p) <- "control.dcm"
+  return(p)
 }
 
 
@@ -152,6 +140,10 @@ control.dcm <- function(type,
 #'        0 (the default) prints completion status of entire simulation and
 #'        positive integer \code{x} prints progress after each \code{x} time
 #'        steps.
+#' @param skip.check if \code{TRUE}, skips the error check for parameter values,
+#'        initial conditions, and control settings before running the models.
+#'        This is suggested only if encountering unnecessary errors when running
+#'        new models.
 #' @param ... additional control settings passed to model.
 #'
 #' @details
@@ -188,80 +180,56 @@ control.dcm <- function(type,
 #'
 control.icm <- function(type,
                         nsteps,
-                        nsims,
-                        rec.rand,
-                        b.rand,
-                        d.rand,
-                        initialize.FUN,
-                        infection.FUN,
-                        recovery.FUN,
-                        deaths.FUN,
-                        births.FUN,
-                        get_prev.FUN,
-                        verbose,
-                        verbose.int,
+                        nsims = 1,
+                        rec.rand = TRUE,
+                        b.rand = TRUE,
+                        d.rand = TRUE,
+                        initialize.FUN = initialize.icm,
+                        infection.FUN = infection.icm,
+                        recovery.FUN = recovery.icm,
+                        deaths.FUN = deaths.icm,
+                        births.FUN = births.icm,
+                        get_prev.FUN = get_prev.icm,
+                        verbose = TRUE,
+                        verbose.int = 0,
+                        skip.check = FALSE,
                         ...) {
 
-  ## Pull parameters
-  out <- as.list(match.call(expand.dots = TRUE)[-1])
+  # Get arguments
+  p <- list()
+  formal.args <- formals(sys.function())
+  formal.args[["..."]] <- NULL
+  for (arg in names(formal.args)) {
+    if (as.logical(mget(arg) != "")) {
+      p[arg] <- list(get(arg))
+    }
+  }
+  dot.args <- list(...)
+  names.dot.args <- names(dot.args)
+  if (length(dot.args) > 0) {
+    for (i in 1:length(dot.args)) {
+      p[[names.dot.args[i]]] <- dot.args[[i]]
+    }
+  }
 
 
-  ## Split lists
-  out <- split_list(out)
-
-
-  ## Eval args
-  out <- eval_list(out)
+  ## Module classification
+  p$bi.mods <- grep(".FUN", names(formal.args), value = TRUE)
+  p$user.mods <- grep(".FUN", names.dot.args, value = TRUE)
 
 
   ## Defaults and checks
-  if (is.null(out$type) | !(out$type %in% c("SI", "SIS", "SIR"))) {
+  if (is.null(p$type) | !(p$type %in% c("SI", "SIS", "SIR"))) {
     stop("Specify type as \"SI\", \"SIS\", or \"SIR\" ", call. = FALSE)
   }
-  if (is.null(out$nsteps)) {
+  if (is.null(p$nsteps)) {
     stop("Specify nsteps", call. = FALSE)
   }
-  if (is.null(out$nsims)) {
-    out$nsims <- 1
-  }
-  if (is.null(out$rec.rand)) {
-    out$rec.rand <- TRUE
-  }
-  if (is.null(out$b.rand)) {
-    out$b.rand <- TRUE
-  }
-  if (is.null(out$d.rand)) {
-    out$d.rand <- TRUE
-  }
-  if (is.null(out$initialize.FUN)) {
-    out$initialize.FUN <- initialize.icm
-  }
-  if (is.null(out$infection.FUN)) {
-    out$infection.FUN <- infection.icm
-  }
-  if (is.null(out$recovery.FUN)) {
-    out$recovery.FUN <- recovery.icm
-  }
-  if (is.null(out$deaths.FUN)) {
-    out$deaths.FUN <- deaths.icm
-  }
-  if (is.null(out$births.FUN)) {
-    out$births.FUN <- births.icm
-  }
-  if (is.null(out$get_prev.FUN)) {
-    out$get_prev.FUN <- get_prev.icm
-  }
-  if (missing(verbose)) {
-    out$verbose <- TRUE
-  }
-  if (is.null(out$verbose.int)) {
-    out$verbose.int <- 0
-  }
 
 
   ## Output
-  class(out) <- "control.icm"
-  return(out)
+  class(p) <- "control.icm"
+  return(p)
 }
 
 
@@ -277,6 +245,7 @@ control.icm <- function(type,
 #' @param nsteps number of time steps to simulate the model over. This must be a
 #'        positive integer.
 #' @param nsims the total number of disease simulations.
+#' @param start for dependent simulations, time point to start up simulation.
 #' @param depend if \code{TRUE}, resimulate the network at each time step. This
 #'        occurs by default with two varieties of dependent models: if there are
 #'        any vital dynamic parameters in the model, or if the network model
@@ -300,7 +269,8 @@ control.icm <- function(type,
 #'        to store disease status. A TEA is needed for plotting static networks
 #'        at different time steps and for animating dynamic networks with evolving
 #'        status. TEAs are computationally inefficient for large simulations and
-#'        should be toggled off in those cases.
+#'        should be toggled off in those cases. This argument automatically set
+#'        to \code{FALSE} if \code{delete.nodes=TRUE}.
 #' @param attr.rules a list containing the  rules for setting the attributes of
 #'        incoming nodes, with one list element per attribute to be set (see
 #'        details below).
@@ -322,9 +292,14 @@ control.icm <- function(type,
 #' @param births.FUN module to simulate births or entries, with the default
 #'        function of \code{\link{births.net}}.
 #' @param resim_nets.FUN module to resimulate the network at each time step,
-#'        with the default function of \code{\link{resim_nets}}
+#'        with the default function of \code{\link{resim_nets}}.
+#' @param edges_correct.FUN module to adjust the edges coefficient in response
+#'        to changes to the population size, with the default function of
+#'        \code{\link{edges_correct}} that preserves mean degree.
 #' @param get_prev.FUN module to calculate disease prevalence at each time step,
 #'        with the default function of \code{\link{get_prev.net}}.
+#' @param verbose.FUN module to print simulation progress to screen, with the
+#'        default function of \code{\link{verbose.net}}.
 #' @param set.control.stergm control arguments passed to simulate.stergm. See the
 #'        help file for \code{\link{netdx}} for details and examples on specifying
 #'        this parameter.
@@ -344,11 +319,18 @@ control.icm <- function(type,
 #'        containing full edge history for each simulation. If \code{delete.nodes}
 #'        is set to \code{TRUE}, this will only contain a static network with the
 #'        edge configuration at the final time step of each simulation.
+#' @param save.other a vector of elements on the \code{dat} master data list
+#'        to save out after each simulation. One example for built-in models is
+#'        the attribute list, "attr", at the final time step.
 #' @param verbose if \code{TRUE}, print model progress to the console.
 #' @param verbose.int time step interval for printing progress to console, where
 #'        0 prints completion status of entire simulation and positive integer
 #'        \code{x} prints progress after each \code{x} time steps. The default
 #'        is to print progress after each time step.
+#' @param skip.check if \code{TRUE}, skips the error check for parameter values,
+#'        initial conditions, and control settings before running the models.
+#'        This is suggested only if encountering unnecessary errors when running
+#'        new models.
 #' @param ... additional control settings passed to model.
 #'
 #' @details
@@ -378,10 +360,10 @@ control.icm <- function(type,
 #'        with no variation.
 #' }
 #' For example, the rules list
-#' \code{attr.rules = list(race = "t1", sex = "current", status = 0)}
+#' \code{attr.rules = list(race = "t1", sex = "current", status = "s")}
 #' specifies how the race, sex, and status attributes should be set for incoming
 #' nodes. By default, the rule is "current" for all attributes except status,
-#' in which case it is 0 (that is, all incoming nodes are susceptible).
+#' in which case it is "s" (that is, all incoming nodes are susceptible).
 #'
 #' @section New Modules:
 #' Built-in network models use a set of module functions that specify how the
@@ -407,124 +389,93 @@ control.icm <- function(type,
 #'
 control.net <- function(type,
                         nsteps,
-                        nsims,
+                        start = 1,
+                        nsims = 1,
                         depend,
-                        rec.rand,
-                        b.rand,
-                        d.rand,
-                        tea.status,
+                        rec.rand = TRUE,
+                        b.rand = TRUE,
+                        d.rand = TRUE,
+                        tea.status = TRUE,
                         attr.rules,
                         epi.by,
                         pid.prefix,
-                        initialize.FUN,
-                        infection.FUN,
-                        recovery.FUN,
-                        deaths.FUN,
-                        births.FUN,
-                        resim_nets.FUN,
-                        get_prev.FUN,
+                        initialize.FUN = initialize.net,
+                        infection.FUN = infection.net,
+                        recovery.FUN = recovery.net,
+                        deaths.FUN = deaths.net,
+                        births.FUN = births.net,
+                        resim_nets.FUN = resim_nets,
+                        edges_correct.FUN = edges_correct,
+                        get_prev.FUN = get_prev.net,
+                        verbose.FUN = verbose.net,
                         set.control.stergm,
-                        save.nwstats,
-                        nwstats.formula,
-                        delete.nodes,
-                        save.transmat,
-                        save.network,
-                        verbose,
-                        verbose.int,
+                        save.nwstats = TRUE,
+                        nwstats.formula = "formation",
+                        delete.nodes = FALSE,
+                        save.transmat = TRUE,
+                        save.network = TRUE,
+                        save.other,
+                        verbose = TRUE,
+                        verbose.int = 1,
+                        skip.check = FALSE,
                         ...) {
 
-  ## Pull parameters
-  out <- as.list(match.call(expand.dots = TRUE)[-1])
+  # Get arguments
+  p <- list()
+  formal.args <- formals(sys.function())
+  formal.args[["..."]] <- NULL
+  for (arg in names(formal.args)) {
+    if (as.logical(mget(arg) != "")) {
+      p[arg] <- list(get(arg))
+    }
+  }
+  dot.args <- list(...)
+  names.dot.args <- names(dot.args)
+  if (length(dot.args) > 0) {
+    for (i in 1:length(dot.args)) {
+      p[[names.dot.args[i]]] <- dot.args[[i]]
+    }
+  }
 
 
-  ## Split lists
-  out <- split_list(out, exclude = "attr.rules")
-
-
-  ## Eval args
-  out <- eval_list(out)
+  ## Module classification
+  p$bi.mods <- grep(".FUN", names(formal.args), value = TRUE)
+  p$user.mods <- grep(".FUN", names.dot.args, value = TRUE)
 
 
   ## Defaults and checks
-  if (is.null(out$type) | !(out$type %in% c("SI", "SIS", "SIR"))) {
+  if (is.null(p$type) | !(p$type %in% c("SI", "SIS", "SIR"))) {
     stop("Specify type as \"SI\", \"SIS\", or \"SIR\" ")
   }
-  if (is.null(out$nsteps)) {
+  if (is.null(p$nsteps)) {
     stop("Specify nsteps")
   }
-  if (is.null(out$nsims)) {
-    out$nsims <- 1
-  }
-  if (is.null(out$rec.rand)) {
-    out$rec.rand <- TRUE
-  }
-  if (is.null(out$b.rand)) {
-    out$b.rand <- TRUE
-  }
-  if (is.null(out$d.rand)) {
-    out$d.rand <- TRUE
-  }
-  if (is.null(out$tea.status)) {
-    out$tea.status <- TRUE
-  }
+
   if (missing(attr.rules)) {
-    out$attr.rules <- list()
+    p$attr.rules <- list()
   }
-  if (!is.null(out$epi.by)) {
-    if (length(out$epi.by) > 1) {
+
+  if (!is.null(p$epi.by)) {
+    if (length(p$epi.by) > 1) {
       stop("Length of epi.by currently limited to 1")
     } else {
-      out$epi.by <- epi.by
+      p$epi.by <- epi.by
     }
   }
-  if (is.null(out$initialize.FUN)) {
-    out$initialize.FUN <- initialize.net
-  }
-  if (is.null(out$infection.FUN)) {
-    out$infection.FUN <- infection.net
-  }
-  if (is.null(out$recovery.FUN)) {
-    out$recovery.FUN <- recovery.net
-  }
-  if (is.null(out$deaths.FUN)) {
-    out$deaths.FUN <- deaths.net
-  }
-  if (is.null(out$births.FUN)) {
-    out$births.FUN <- births.net
-  }
-  if (is.null(out$resim_nets.FUN)) {
-    out$resim_nets.FUN <- resim_nets
-  }
-  if (is.null(out$get_prev.FUN)) {
-    out$get_prev.FUN <- get_prev.net
-  }
-  if (is.null(out$set.control.stergm)) {
-    out$set.control.stergm <- control.simulate.network(MCMC.burnin.min = 1000)
-  }
-  if (is.null(out$save.nwstats)) {
-    out$save.nwstats <- TRUE
-  }
-  if (is.null(out$delete.nodes)) {
-    out$delete.nodes <- FALSE
-  }
-  if (out$delete.nodes == TRUE) {
-    out$tea.status <- FALSE
-  }
-  if (is.null(out$save.transmat)) {
-    out$save.transmat <- TRUE
-  }
-  if (is.null(out$save.network)) {
-    out$save.network <- TRUE
-  }
-  if (missing(verbose)) {
-    out$verbose <- TRUE
-  }
-  if (is.null(out$verbose.int)) {
-    out$verbose.int <- 1
+
+  if (is.null(p$set.control.stergm)) {
+    p$set.control.stergm <- control.simulate.network(MCMC.burnin.min = 1000)
   }
 
+  if (p$delete.nodes == TRUE) {
+    p$tea.status <- FALSE
+  }
+
+  if (p$start > 1) {
+    p$skip.check <- TRUE
+  }
 
   ## Output
-  class(out) <- "control.net"
-  return(out)
+  class(p) <- "control.net"
+  return(p)
 }
