@@ -4,7 +4,7 @@
 #' @description This function simulates death for use in \code{\link{icm}}
 #'              simulations.
 #'
-#' @param all master data list object.
+#' @param dat master data list object.
 #' @param at current time step.
 #'
 #' @seealso \code{\link{icm}}
@@ -12,142 +12,142 @@
 #' @export
 #' @keywords internal
 #'
-deaths.icm <- function(all, at) {
+deaths.icm <- function(dat, at) {
 
   # Conditions --------------------------------------------------------------
-  if (all$param$vital == FALSE) {
-    return(all)
+  if (dat$param$vital == FALSE) {
+    return(dat)
   }
 
 
   # Variables ---------------------------------------------------------------
-  groups <- all$param$groups
-  group <- all$attr$group
+  groups <- dat$param$groups
+  group <- dat$attr$group
 
 
   # Susceptible deaths ------------------------------------------------------
   nDeaths <- nDeathsG2 <- 0
-  idsElig <- which(all$attr$active == 1 & all$attr$status == 0)
+  idsElig <- which(dat$attr$active == 1 & dat$attr$status == "s")
   nElig <- length(idsElig)
   if (nElig > 0) {
 
     gElig <- group[idsElig]
-    rates <- c(all$param$ds.rate, all$param$ds.rate.g2)
+    rates <- c(dat$param$ds.rate, dat$param$ds.rate.g2)
     ratesElig <- rates[gElig]
 
-    if (all$control$d.rand == TRUE) {
+    if (dat$control$d.rand == TRUE) {
       vecDeaths <- which(rbinom(nElig, 1, ratesElig) == 1)
       if (length(vecDeaths) > 0) {
         idsDth <- idsElig[vecDeaths]
         nDeaths <- sum(group[idsDth] == 1)
         nDeathsG2 <- sum(group[idsDth] == 2)
-        all$attr$active[idsDth] <- 0
+        dat$attr$active[idsDth] <- 0
       }
     } else {
       nDeaths <- min(round(sum(ratesElig[gElig == 1])), sum(gElig == 1))
-      all$attr$active[ssample(idsElig[gElig == 1], nDeaths)] <- 0
+      dat$attr$active[ssample(idsElig[gElig == 1], nDeaths)] <- 0
       if (groups == 2) {
         nDeathsG2 <- min(round(sum(ratesElig[gElig == 2])), sum(gElig == 2))
-        all$attr$active[ssample(idsElig[gElig == 2], nDeaths)] <- 0
+        dat$attr$active[ssample(idsElig[gElig == 2], nDeaths)] <- 0
       }
     }
   }
 
   if (at == 2) {
-    all$out$ds.flow <- c(0, nDeaths)
+    dat$epi$ds.flow <- c(0, nDeaths)
     if (groups == 2) {
-      all$out$ds.flow.g2 <- c(0, nDeathsG2)
+      dat$epi$ds.flow.g2 <- c(0, nDeathsG2)
     }
   } else {
-    all$out$ds.flow[at] <- nDeaths
+    dat$epi$ds.flow[at] <- nDeaths
     if (groups == 2) {
-      all$out$ds.flow.g2[at] <- nDeathsG2
+      dat$epi$ds.flow.g2[at] <- nDeathsG2
     }
   }
 
 
   # Infected Deaths ---------------------------------------------------------
   nDeaths <- nDeathsG2 <- 0
-  idsElig <- which(all$attr$active == 1 & all$attr$status == 1)
+  idsElig <- which(dat$attr$active == 1 & dat$attr$status == "i")
   nElig <- length(idsElig)
   if (nElig > 0) {
 
     gElig <- group[idsElig]
-    rates <- c(all$param$di.rate, all$param$di.rate.g2)
+    rates <- c(dat$param$di.rate, dat$param$di.rate.g2)
     ratesElig <- rates[gElig]
 
-    if (all$control$d.rand == TRUE) {
+    if (dat$control$d.rand == TRUE) {
       vecDeaths <- which(rbinom(nElig, 1, ratesElig) == 1)
       if (length(vecDeaths) > 0) {
         idsDth <- idsElig[vecDeaths]
         nDeaths <- sum(group[idsDth] == 1)
         nDeathsG2 <- sum(group[idsDth] == 2)
-        all$attr$active[idsDth] <- 0
+        dat$attr$active[idsDth] <- 0
       }
     } else {
       nDeaths <- min(round(sum(ratesElig[gElig == 1])), sum(gElig == 1))
-      all$attr$active[ssample(idsElig[gElig == 1], nDeaths)] <- 0
+      dat$attr$active[ssample(idsElig[gElig == 1], nDeaths)] <- 0
       if (groups == 2) {
         nDeathsG2 <- min(round(sum(ratesElig[gElig == 2])), sum(gElig == 2))
-        all$attr$active[ssample(idsElig[gElig == 2], nDeaths)] <- 0
+        dat$attr$active[ssample(idsElig[gElig == 2], nDeaths)] <- 0
       }
     }
   }
 
   if (at == 2) {
-    all$out$di.flow <- c(0, nDeaths)
+    dat$epi$di.flow <- c(0, nDeaths)
     if (groups == 2) {
-      all$out$di.flow.g2 <- c(0, nDeathsG2)
+      dat$epi$di.flow.g2 <- c(0, nDeathsG2)
     }
   } else {
-    all$out$di.flow[at] <- nDeaths
+    dat$epi$di.flow[at] <- nDeaths
     if (groups == 2) {
-      all$out$di.flow.g2[at] <- nDeathsG2
+      dat$epi$di.flow.g2[at] <- nDeathsG2
     }
   }
 
 
   # Recovered Deaths --------------------------------------------------------
   nDeaths <- nDeathsG2 <- 0
-  idsElig <- which(all$attr$active == 1 & all$attr$status == 2)
+  idsElig <- which(dat$attr$active == 1 & dat$attr$status == "r")
   nElig <- length(idsElig)
   if (nElig > 0) {
 
     gElig <- group[idsElig]
-    rates <- c(all$param$dr.rate, all$param$dr.rate.g2)
+    rates <- c(dat$param$dr.rate, dat$param$dr.rate.g2)
     ratesElig <- rates[gElig]
 
-    if (all$control$d.rand == TRUE) {
+    if (dat$control$d.rand == TRUE) {
       vecDeaths <- which(rbinom(nElig, 1, ratesElig) == 1)
       if (length(vecDeaths) > 0) {
         idsDth <- idsElig[vecDeaths]
         nDeaths <- sum(group[idsDth] == 1)
         nDeathsG2 <- sum(group[idsDth] == 2)
-        all$attr$active[idsDth] <- 0
+        dat$attr$active[idsDth] <- 0
       }
     } else {
       nDeaths <- min(round(sum(ratesElig[gElig == 1])), sum(gElig == 1))
-      all$attr$active[ssample(idsElig[gElig == 1], nDeaths)] <- 0
+      dat$attr$active[ssample(idsElig[gElig == 1], nDeaths)] <- 0
       if (groups == 2) {
         nDeathsG2 <- min(round(sum(ratesElig[gElig == 2])), sum(gElig == 2))
-        all$attr$active[ssample(idsElig[gElig == 2], nDeaths)] <- 0
+        dat$attr$active[ssample(idsElig[gElig == 2], nDeaths)] <- 0
       }
     }
   }
 
   if (at == 2) {
-    all$out$dr.flow <- c(0, nDeaths)
+    dat$epi$dr.flow <- c(0, nDeaths)
     if (groups == 2) {
-      all$out$dr.flow.g2 <- c(0, nDeathsG2)
+      dat$epi$dr.flow.g2 <- c(0, nDeathsG2)
     }
   } else {
-    all$out$dr.flow[at] <- nDeaths
+    dat$epi$dr.flow[at] <- nDeaths
     if (groups == 2) {
-      all$out$dr.flow.g2[at] <- nDeathsG2
+      dat$epi$dr.flow.g2[at] <- nDeathsG2
     }
   }
 
-  return(all)
+  return(dat)
 }
 
 
@@ -157,7 +157,7 @@ deaths.icm <- function(all, at) {
 #' @description This function simulates birth for use in \code{\link{icm}}
 #'              simulations.
 #'
-#' @param all master data list object.
+#' @param dat master data list object.
 #' @param at current time step.
 #'
 #' @seealso \code{\link{icm}}
@@ -165,19 +165,19 @@ deaths.icm <- function(all, at) {
 #' @export
 #' @keywords internal
 #'
-births.icm <- function(all, at) {
+births.icm <- function(dat, at) {
 
   # Conditions --------------------------------------------------------------
-  if (all$param$vital == FALSE) {
-    return(all)
+  if (dat$param$vital == FALSE) {
+    return(dat)
   }
 
   # Variables ---------------------------------------------------------------
-  b.rate <- all$param$b.rate
-  b.rate.g2 <- all$param$b.rate.g2
-  b.rand <- all$control$b.rand
-  groups <- all$param$groups
-  nOld <- all$out$num[at-1]
+  b.rate <- dat$param$b.rate
+  b.rate.g2 <- dat$param$b.rate.g2
+  b.rand <- dat$control$b.rand
+  groups <- dat$param$groups
+  nOld <- dat$epi$num[at-1]
 
 
   # Process -----------------------------------------------------------------
@@ -192,7 +192,7 @@ births.icm <- function(all, at) {
     }
   }
   if (groups == 2) {
-    nOldG2 <- all$out$num.g2[at-1]
+    nOldG2 <- dat$epi$num.g2[at-1]
     if (b.rand == TRUE) {
       if (is.na(b.rate.g2)) {
         nBirths <- sum(rbinom(nOld, 1, b.rate))
@@ -215,25 +215,25 @@ births.icm <- function(all, at) {
 
   ## Set attributes
   totBirths <- nBirths + nBirthsG2
-  all$attr$active <- c(all$attr$active, rep(1, totBirths))
-  all$attr$group <- c(all$attr$group, c(rep(1, nBirths), rep(2, nBirthsG2)))
-  all$attr$status <- c(all$attr$status, rep(0, totBirths))
-  all$attr$infTime <- c(all$attr$infTime, rep(NA, totBirths))
+  dat$attr$active <- c(dat$attr$active, rep(1, totBirths))
+  dat$attr$group <- c(dat$attr$group, c(rep(1, nBirths), rep(2, nBirthsG2)))
+  dat$attr$status <- c(dat$attr$status, rep("s", totBirths))
+  dat$attr$infTime <- c(dat$attr$infTime, rep(NA, totBirths))
 
 
   # Output ------------------------------------------------------------------
   if (at == 2) {
-    all$out$b.flow <- c(0, nBirths)
+    dat$epi$b.flow <- c(0, nBirths)
   } else {
-    all$out$b.flow[at] <- nBirths
+    dat$epi$b.flow[at] <- nBirths
   }
-  if (all$param$groups == 2) {
+  if (dat$param$groups == 2) {
     if (at == 2) {
-      all$out$b.flow.g2 <- c(0, nBirthsG2)
+      dat$epi$b.flow.g2 <- c(0, nBirthsG2)
     } else {
-      all$out$b.flow.g2[at] <- nBirthsG2
+      dat$epi$b.flow.g2[at] <- nBirthsG2
     }
   }
 
-  return(all)
+  return(dat)
 }
